==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/SavedqueryvisualizationCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Savedqueryvisualization;
import microsoft.dynamics.crm.entity.request.SavedqueryvisualizationRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class SavedqueryvisualizationCollectionRequest extends CollectionPageEntityRequest<Savedqueryvisualization, SavedqueryvisualizationRequest>{

    protected ContextPath contextPath;

    public SavedqueryvisualizationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Savedqueryvisualization.class, cp -> new SavedqueryvisualizationRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest savedQueryVisualization_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("SavedQueryVisualization_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest savedQueryVisualization_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("SavedQueryVisualization_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Savedqueryvisualization> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Savedqueryvisualization.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/SavedqueryvisualizationCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Savedqueryvisualization;
import microsoft.dynamics.crm.entity.request.SavedqueryvisualizationRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class SavedqueryvisualizationCollectionRequest extends CollectionPageEntityRequest<Savedqueryvisualization, SavedqueryvisualizationRequest>{

    protected ContextPath contextPath;

    public SavedqueryvisualizationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Savedqueryvisualization.class, cp -> new SavedqueryvisualizationRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest savedQueryVisualization_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("SavedQueryVisualization_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest savedQueryVisualization_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("SavedQueryVisualization_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Savedqueryvisualization> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Savedqueryvisualization.class, _parameters);
    }

}
